package com.fs.hisStore.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.hisStore.mapper.FsStoreOrderOfflineItemScrmMapper;
import com.fs.hisStore.domain.FsStoreOrderOfflineItemScrm;
import com.fs.hisStore.service.IFsStoreOrderOfflineItemScrmService;

/**
 * 线下订单详情Service业务层处理
 *
 * @author fs
 * @date 2024-10-29
 */
@Service
public class FsStoreOrderOfflineItemScrmServiceImpl implements IFsStoreOrderOfflineItemScrmService
{
    @Autowired
    private FsStoreOrderOfflineItemScrmMapper fsStoreOrderOfflineItemMapper;

    /**
     * 查询线下订单详情
     *
     * @param itemId 线下订单详情ID
     * @return 线下订单详情
     */
    @Override
    public FsStoreOrderOfflineItemScrm selectFsStoreOrderOfflineItemById(Long itemId)
    {
        return fsStoreOrderOfflineItemMapper.selectFsStoreOrderOfflineItemById(itemId);
    }

    /**
     * 查询线下订单详情列表
     *
     * @param fsStoreOrderOfflineItem 线下订单详情
     * @return 线下订单详情
     */
    @Override
    public List<FsStoreOrderOfflineItemScrm> selectFsStoreOrderOfflineItemList(FsStoreOrderOfflineItemScrm fsStoreOrderOfflineItem)
    {
        return fsStoreOrderOfflineItemMapper.selectFsStoreOrderOfflineItemList(fsStoreOrderOfflineItem);
    }

    /**
     * 新增线下订单详情
     *
     * @param fsStoreOrderOfflineItem 线下订单详情
     * @return 结果
     */
    @Override
    public int insertFsStoreOrderOfflineItem(FsStoreOrderOfflineItemScrm fsStoreOrderOfflineItem)
    {
        return fsStoreOrderOfflineItemMapper.insertFsStoreOrderOfflineItem(fsStoreOrderOfflineItem);
    }

    /**
     * 修改线下订单详情
     *
     * @param fsStoreOrderOfflineItem 线下订单详情
     * @return 结果
     */
    @Override
    public int updateFsStoreOrderOfflineItem(FsStoreOrderOfflineItemScrm fsStoreOrderOfflineItem)
    {
        return fsStoreOrderOfflineItemMapper.updateFsStoreOrderOfflineItem(fsStoreOrderOfflineItem);
    }

    /**
     * 批量删除线下订单详情
     *
     * @param itemIds 需要删除的线下订单详情ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreOrderOfflineItemByIds(Long[] itemIds)
    {
        return fsStoreOrderOfflineItemMapper.deleteFsStoreOrderOfflineItemByIds(itemIds);
    }

    /**
     * 删除线下订单详情信息
     *
     * @param itemId 线下订单详情ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreOrderOfflineItemById(Long itemId)
    {
        return fsStoreOrderOfflineItemMapper.deleteFsStoreOrderOfflineItemById(itemId);
    }
}
