package com.fs.hisStore.controller;

import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.core.page.TableDataInfo;
import com.fs.common.enums.BusinessType;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.hisStore.domain.FsStoreOrderOfflineItemScrm;
import com.fs.hisStore.service.IFsStoreOrderOfflineItemScrmService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 线下订单详情Controller
 *
 * @author fs
 * @date 2024-10-29
 */
@RestController
@RequestMapping("/store/storeOrderOfflineItem/store")
public class FsStoreOrderOfflineItemScrmController extends BaseController
{
    @Autowired
    private IFsStoreOrderOfflineItemScrmService fsStoreOrderOfflineItemService;

    /**
     * 查询线下订单详情列表
     */
    @PreAuthorize("@ss.hasPermi('storeOrderOfflineItem:store:list')")
    @GetMapping("/list")
    public TableDataInfo list(FsStoreOrderOfflineItemScrm fsStoreOrderOfflineItem)
    {
        startPage();
        List<FsStoreOrderOfflineItemScrm> list = fsStoreOrderOfflineItemService.selectFsStoreOrderOfflineItemList(fsStoreOrderOfflineItem);
        return getDataTable(list);
    }

    /**
     * 导出线下订单详情列表
     */
    @PreAuthorize("@ss.hasPermi('storeOrderOfflineItem:store:export')")
    @Log(title = "线下订单详情", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(FsStoreOrderOfflineItemScrm fsStoreOrderOfflineItem)
    {
        List<FsStoreOrderOfflineItemScrm> list = fsStoreOrderOfflineItemService.selectFsStoreOrderOfflineItemList(fsStoreOrderOfflineItem);
        ExcelUtil<FsStoreOrderOfflineItemScrm> util = new ExcelUtil<FsStoreOrderOfflineItemScrm>(FsStoreOrderOfflineItemScrm.class);
        return util.exportExcel(list, "store");
    }

    /**
     * 获取线下订单详情详细信息
     */
    @PreAuthorize("@ss.hasPermi('storeOrderOfflineItem:store:query')")
    @GetMapping(value = "/{itemId}")
    public AjaxResult getInfo(@PathVariable("itemId") Long itemId)
    {
        return AjaxResult.success(fsStoreOrderOfflineItemService.selectFsStoreOrderOfflineItemById(itemId));
    }

    /**
     * 新增线下订单详情
     */
    @PreAuthorize("@ss.hasPermi('storeOrderOfflineItem:store:add')")
    @Log(title = "线下订单详情", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FsStoreOrderOfflineItemScrm fsStoreOrderOfflineItem)
    {
        return toAjax(fsStoreOrderOfflineItemService.insertFsStoreOrderOfflineItem(fsStoreOrderOfflineItem));
    }

    /**
     * 修改线下订单详情
     */
    @PreAuthorize("@ss.hasPermi('storeOrderOfflineItem:store:edit')")
    @Log(title = "线下订单详情", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FsStoreOrderOfflineItemScrm fsStoreOrderOfflineItem)
    {
        return toAjax(fsStoreOrderOfflineItemService.updateFsStoreOrderOfflineItem(fsStoreOrderOfflineItem));
    }

    /**
     * 删除线下订单详情
     */
    @PreAuthorize("@ss.hasPermi('storeOrderOfflineItem:store:remove')")
    @Log(title = "线下订单详情", businessType = BusinessType.DELETE)
	@DeleteMapping("/{itemIds}")
    public AjaxResult remove(@PathVariable Long[] itemIds)
    {
        return toAjax(fsStoreOrderOfflineItemService.deleteFsStoreOrderOfflineItemByIds(itemIds));
    }
}
